==> haskell-xml-types-0.3.8-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xml-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 xml-types
version:              0.3.8
visibility:           public
id:                   xml-types-0.3.8-144bFK4Wa4uGyLKj6w2QbB
key:                  xml-types-0.3.8-144bFK4Wa4uGyLKj6w2QbB
license:              MIT
maintainer:           Stephen Paul Weber <singpolyma@singpolyma.net>
author:               John Millikin <jmillikin@gmail.com>
stability:            experimental
homepage:             https://git.singpolyma.net/xml-types-haskell
synopsis:             Basic types for representing XML
description:
    Basic types for representing XML.

    The idea is to have a full set of appropriate types, which various XML
    libraries can share. Instead of having equivalent-but-incompatible types
    for every binding, parser, or client, they all share the same types can
    can thus interoperate easily.

    This library contains complete types for most parts of an XML document,
    including the prologue, node tree, and doctype. Some basic combinators
    are included for common tasks, including traversing the node tree and
    filtering children.

category:             Text, XML
abi:                  30de341452ccde9b6f5b02f80e9564f3
exposed:              True
exposed-modules:      Data.XML.Types
import-dirs:          /usr/lib/ghc-9.0.1/site-local/xml-types-0.3.8
library-dirs:         /usr/lib/ghc-9.0.1/site-local/xml-types-0.3.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/xml-types-0.3.8
hs-libraries:         HSxml-types-0.3.8-144bFK4Wa4uGyLKj6w2QbB
depends:              base-4.15.0.0 deepseq-1.4.5.0 text-1.2.4.1
haddock-interfaces:   /usr/share/doc/haskell-xml-types/html/xml-types.haddock
haddock-html:         /usr/share/doc/haskell-xml-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xml-types-0.3.8-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xml-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 xml-types
version:              0.3.8
visibility:           public
id:                   xml-types-0.3.8-5QCBKSWiifmEtQB2jlqHYu
key:                  xml-types-0.3.8-5QCBKSWiifmEtQB2jlqHYu
license:              MIT
maintainer:           Stephen Paul Weber <singpolyma@singpolyma.net>
author:               John Millikin <jmillikin@gmail.com>
stability:            experimental
homepage:             https://git.singpolyma.net/xml-types-haskell
synopsis:             Basic types for representing XML
description:
    Basic types for representing XML.

    The idea is to have a full set of appropriate types, which various XML
    libraries can share. Instead of having equivalent-but-incompatible types
    for every binding, parser, or client, they all share the same types can
    can thus interoperate easily.

    This library contains complete types for most parts of an XML document,
    including the prologue, node tree, and doctype. Some basic combinators
    are included for common tasks, including traversing the node tree and
    filtering children.

category:             Text, XML
abi:                  32b36c70674cbfbd13a4ba0741eb2c9b
exposed:              True
exposed-modules:      Data.XML.Types
import-dirs:          /usr/lib/ghc-9.0.2/site-local/xml-types-0.3.8
library-dirs:         /usr/lib/ghc-9.0.2/site-local/xml-types-0.3.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/xml-types-0.3.8
hs-libraries:         HSxml-types-0.3.8-5QCBKSWiifmEtQB2jlqHYu
depends:              base-4.15.1.0 deepseq-1.4.5.0 text-1.2.5.0
haddock-interfaces:   /usr/share/doc/haskell-xml-types/html/xml-types.haddock
haddock-html:         /usr/share/doc/haskell-xml-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
